@@ -13,6 +13,7 @@ from .loxiroomcontrollerv2 import LoxIntelligentRoomControllerV2
 from .loxinfoonlyanalog import LoxInfoOnlyAnalog
 from .loxinfoonlydigital import LoxInfoOnlyDigital
 from .loxclimatecontroller import LoxClimateController
+from .loxjalousie import LoxJalousie
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -191,15 +192,15 @@ class MessageBody:
                             if stateName == "controls":
                                 controls = json.loads(text)
                                 for con in controls:
-                                    _LOGGER.debug("  climate control - uuid: {0} demand: {1}".format(con['uuid'], con['demand']))
-                                    if con['uuid'] in config_data.fieldmap:
-                                        _LOGGER.debug("A")
-                                        mapentry2 = config_data.fieldmap[con['uuid']]
-                                        _LOGGER.debug("B")
-                                        device2 = mapentry["device"]
-                                        _LOGGER.debug("C")
-                                        device2.set_value("demand", con['demand'])
-                                        _LOGGER.debug("D")
+                                    con_uuid = con['uuid']
+                                    con_demand = con['demand']
+
+                                    _LOGGER.debug("  climate control - uuid: {0} demand: {1}".format(con_uuid, con_demand))
+
+                                    for rck,rcv in config_data.roomcontrollers.items():
+                                        #_LOGGER.debug("     available controller: {0}".format(rck))
+                                        if rck == con_uuid:
+                                            rcv.set_value("demand", con_demand)
 
 
 
